@@ -2609,7 +2609,7 @@ static const R_CallMethodDef callMethods [] = {
     {NULL, NULL, 0}
 }; 
 
-void R_init_cmfrec(DllInfo *info)
+void attribute_visible R_init_cmfrec(DllInfo *info)
 {
     R_registerRoutines(info, NULL, callMethods, NULL, NULL);
     R_useDynamicSymbols(info, TRUE);
